@echo off

rem ------ THEATRE MANAGER POSTGRES DATABASE BACKUP SCRIPT  version 1.6 ----------------------------
rem Created by: Arts Management Systems Limited - Calgary Alberta Canada (403) 536-1214 http://www.artsman.com
rem
rem This database backup script integrates with Theatre Manager to support provide an automatic  
rem backup script of the PostgreSQL database.   It also DELETES an backup files that are older than xx days
rem
rem if desired, you can specify a remote FTP site tosend the database to
rem
rem If you see this and want Theatre Manager to use for your own venue, please check us out at http://www.artsman.com  
rem
rem Alter this source code as you see fit to suit your needs, but if you do, Arts Management Systems 
rem is not responsible for supporting or debugging errors that may occur.
rem
rem changes
rem 091220 added code to write back the last backup to the database
rem 091221 added code to vacuum analyse the database to make sure its tip top
rem ------------------------------------------------------------------------------------------------


rem ------ USAGE NOTES ----------------------------------------------------------------------------- 
rem In order to use this script please setup all the variables to match your servers setup.
rem
rem Please note that this script assumes that it is being run off the server machine and that
rem the server has 'trust' enabled for 127.0.0.1 or localhost in the pg_hba.conf file for PostgreSQL.
rem
rem The realdate.com program from http://www.huweb.hu/maques/realdate.htm
rem is assumed to be in the BoxOffice folder, where-ever the user wants it.  So if you change
rem the backup path, then please move realdate.com program into that folder.
rem
rem Based on the default settings, the standard location of the files are:
rem    C:\BoxOffice               - the main BoxOffice data folder
rem    C:\BoxOffice\Backups       - the location where the database backups will be saved
rem    C:\BoxOffice\BackupTM.bat  - this file you are reading.  It is the backup script.
rem    C:\BoxOffice\delage32.com  - required to be in the BoxOffice folder
rem
rem To setup the Windows Scheduled Task to run this script every day:
rem                          1) In Windows, goto Start >> Settings >> Control Panel >> Scheduled Tasks
rem                          2) Double Click on Add Scheduled Task
rem                          3) Follow the prompts to run the program C:\BoxOffice\BackupTM.bat
rem                          4) note: you can set this to run multiple times in one day if you wish
rem 
rem If you want to run this backup script outside of a regular scheduled backup:
rem    Option A)  Via the windows command prompt
rem			1) In Windows, goto Start >> Run...
rem			2) Enter cmd  
rem			3) Click OK
rem			4) Enter C:\BoxOffice\BackupTM.bat
rem			5) Press <ENTER> or <RETURN>
rem
rem    Option B)  Via the created Windows Scheduled Task
rem                          1) In Windows, goto Start >> Settings >> Control Panel >> Scheduled Tasks
rem                          2) Right Mouse Click on the schedule task that you created
rem                          3) Select 'Run' from the pop-up context menu
rem
rem To edit the Windows Scheduled Task that you created:
rem                           1) In Windows, goto Start >> Settings >> Control Panel >> Scheduled Tasks
rem                          2) Right Mouse Click on the schedule task that you created
rem                          3) Select 'Properties' from the pop-up context menu
rem ------------------------------------------------------------------------------------------------


rem ------ CUSTOMIZE SCRIPT VARIABLES HERE ---------------------------------------------------------

rem Step #1 - Change the 'DATABASE_NAME' to be the name of the database you need to backup
rem		Note: This setting is normally always changed.  Set it to match exactly the PostgreSQL database name
rem
set DATABASE_NAME=TheatreManagerDemo


rem Step #2 - Change the 'POSTGRESQL_PATH' to be the location where PostgreSQL is installed
rem		Note: This setting is normally set as   C:\Program Files\PostgreSQL\8.4
rem                      on 64 bit machines, this is        C:\Program Files (x86)\PostgreSQL\8.4
rem
set POSTGRESQL_PATH=C:\Program Files\PostgreSQL\8.4


rem Step #3 - Change the 'BOXOFFICE_DIR'to be the location of the main BoxOffice folder.
rem		Note: This setting is normally set as   C:\BoxOffice
rem
set BOXOFFICE_DIR=C:\BoxOffice


rem Step #4 - Change the 'BACKUP_FOLDER' to be the name of the folder where the backup files will be saved.
rem		Note: This setting is normally set as   Backups
rem			  
set BACKUP_FOLDER=Backups

rem Step #5 - Change the 'KEEP_FILES_FOR' to be the number of days that the backup files will be retained.
rem		Note: This setting is normally set as   30
rem			  Set this to 0 if you want to keep the backup files forever
rem			  
set KEEP_FILES_FOR=30

rem Step #6 indicate if you want to send information to an FTP site afterward by entering the following parameters
rem              Note:  if the server is left blank, then no FTP will occur
rem                         and make absolutely sur that there is no spaces after the text on the commands

set FTPSERVER=
rem set FTPSERVER=yourserver
set FTPUsername=yourusername
set FTPPassword=yourpassword


rem ------ DO NOT MAKE CHANGES BELOW HERE ----------------------------------------------------------

set hours=%Time:~0,1%
if ("%hours%") == (" ") set hours=0

set datestr=%Date:~-4,4%%Date:~-10,2%%Date:~-7,2%_%hours%%Time:~1,1%%Time:~3,2%%Time:~6,2%
set sqltime=%Date:~-4,4%-%Date:~-10,2%-%Date:~-7,2% %hours%%Time:~1,1%:%Time:~3,2%:%Time:~6,2%
set BACKUP_PATH=%BOXOFFICE_DIR%\%BACKUP_FOLDER%

rem parameters are:
rem  -U POSTGRES
rem  -o    include OID's in the dump  unique rowID's
rem  -v    verbose.  show the files as they are being done (optional)
rem  -F c  dump in custom Postgres format.
rem  -b    include blobs in the dump. These are things like theatre maps
rem  -Z 9  compression level for the dump.  Do the most compression
rem -U postgres  runs the command under the postgres user id

"%POSTGRESQL_PATH%\bin\pg_dump.exe" -U postgres -v -F c -Z 9 %DATABASE_NAME% > "%BACKUP_PATH%\%DATABASE_NAME%_TM_%datestr%.backup"

echo Backup completed.  Compressed database is located at %BACKUP_PATH%\%DATABASE_NAME%_TM_%datestr%.backup

rem  update the last  time the backup script got this far along in the database for warning purposes
echo Setting last backup time in %DATABASE_NAME%
set updatecmd="update fSystemPreferences set SPR_DATE_LAST_BACKUP_SCRIPT_RUN = TIMESTAMP '%sqltime%';"
"%POSTGRESQL_PATH%\bin\psql.exe" -U postgres -d %DATABASE_NAME% -c %updatecmd%

rem vaccum the database for performance
echo Vacuum analyse the database %DATABASE_NAME%
"%POSTGRESQL_PATH%\bin\psql.exe" -U postgres -d %DATABASE_NAME% -c "vacuum analyse;"

rem -----   now delete the old files using delage32   --------------------------
rem delage32 is written by horst schaeffer   at  http://home.mnet-online.de/horst.muc
rem refer to documentation at http://home.mnet-online.de/horst.muc/win/delage.htm to see the parameters of this command
rem format is generally:
rem         DelAge32 filespec days [options]       
rem key options are:
rem         /preview   - show the files htat would be deleted, but don't delete them
rem        /modified  -use the modified time stamp for comparison (default option)
rem        /created    - use the date created time stamp  (warning... copying a file gives a new created date and retains the modified date)
rem        /includeRO - include read only files in deletion
rem        /includeH   - include hidden files in deletion

if  "%KEEP_FILES_FOR%" == "0" (
	echo Purging of backup files is disabled.
) ELSE (
	echo Purging all backups files older than %KEEP_FILES_FOR% days
	"%BOXOFFICE_DIR%\delage32" "%BACKUP_PATH%\%DATABASE_NAME%_TM_*.*" %KEEP_FILES_FOR% /includeRO /includeH
)	


rem if the FTPSERVER is filled in, then FTP the data up to the  remote server after the backup is done

if  ("%FTPSERVER%") == ("") goto end

rem 	ftp the file to the appropriate place

	echo FTP file to %FTPSERVER% - sending %BACKUP_PATH%\%DATABASE_NAME%_TM_%datestr%.backup
	set FTPscript=%BACKUP_PATH%\ftpscript.txt
	echo %FTPUsername%>%FTPscript%
	echo %FTPpassword%>>%FTPscript%
	echo type binary>>%FTPscript%
	echo put "%BACKUP_PATH%\%DATABASE_NAME%_TM_%datestr%.backup" "%DATABASE_NAME%_TM_%datestr%.backup">>%FTPscript%
	echo quit>>%FTPscript%

	ftp -s:%FTPscript% %FTPSERVER%
	
	del  "%BACKUP_PATH%\ftpscript.txt"

:end
	
Set FTPUsername=***
Set FTPpassword=***
@echo on